# python-trbinance

## TrBinance Python API Wrapper

This is a simple Python API wrapper for the TrBinance cryptocurrency exchange. It allows you to interact with the TrBinance API, perform various operations like fetching account information, trading pairs, placing orders, and more. I will try to make it similar to ccxt conventions, so it should be easy to use for people who have used ccxt before.

## Caution

This is a work in progress. I am not responsible for any losses you may incur while using this library. Use at your own risk. Not all methods are tested properly!

## Installation

```bash
pip install trbinance
```

[Support me by signing up with the referral link](https://www.trbinance.com/account/signup?ref=A42ISN65)
